@@ -12,7 +12,7 @@ logger = logging.getLogger(__name__)
 class MapInfoWidget(WidgetView):
 	widget_x = 125
 	widget_y = 90
-	z_index = 60
+	z_index = 160
 
 	template_name = 'info/mapinfo.xml'
 
@@ -61,7 +61,7 @@ class MapInfoWidget(WidgetView):
 class ServerInfoWidget(WidgetView):
 	widget_x = -160
 	widget_y = 90
-	z_index = 60
+	z_index = 160
 
 	template_name = 'info/serverinfo.xml'
 
@@ -78,13 +78,16 @@ class ServerInfoWidget(WidgetView):
 	async def get_context_data(self):
 		context = await super().get_context_data()
 
-		ladder_min = int(self.app.instance.game.ladder_min)
-		ladder_max = int(self.app.instance.game.ladder_max)
-
-		if ladder_min > 1000:
-			ladder_min = int(ladder_min / 1000)
-		if ladder_max > 1000:
-			ladder_max = int(ladder_max / 1000)
+		ladder_min = None
+		if self.app.instance.game.ladder_min is not None:
+			ladder_min = int(self.app.instance.game.ladder_min)
+			if ladder_min > 1000:
+				ladder_min = int(ladder_min / 1000)
+		ladder_max = None
+		if self.app.instance.game.ladder_max is not None:
+			ladder_max = int(self.app.instance.game.ladder_max)
+			if ladder_max > 1000:
+				ladder_max = int(ladder_max / 1000)
 
 		context.update({
 			'version': version,
