@@ -187,7 +187,7 @@ class MapListView(ManualListView):
 				elif value < 0.0:
 					prefix = '$F66'
 				return '{}{}'.format(prefix, float(value))
-			
+
 		if self.advanced and not self.app.instance.performance_mode:
 			if 'karma' in self.app.instance.apps.apps:
 				fields.append({
@@ -349,17 +349,9 @@ class FolderMapListView(MapListView):
 
 		self.title = 'Folder: ' + self.folder_info['name']
 
-		karma = any(f['index'] == "karma" for f in self.fields)
-		length = any(f['index'] == "local_record" for f in self.fields)
-
 		items = []
 		for item in self.map_list:
-			dict_item = model_to_dict(item)
-			if length:
-				dict_item['local_record'] = times.format_time((item.local['first_record'].score if hasattr(item, 'local') and item.local['first_record'] else 0))
-			if karma and 'karma' in self.app.instance.apps.apps:
-				dict_item['karma'] = (await self.app.instance.apps.apps['karma'].get_map_karma(item))['map_karma']
-			items.append(dict_item)
+			items.append(await self.map_to_dict(item))
 
 		self.cache = items
 		return self.cache
@@ -381,6 +373,11 @@ class FolderMapListView(MapListView):
 		# Remove from folder.
 		await self.folder_manager.remove_map_from_folder(self.folder_instance.id, map_dictionary['id'])
 
+		# Remove from the cache.
+		for item in self.cache:
+			if item['id'] == map_dictionary['id']:
+				self.cache.remove(item)
+
 		# Refresh list.
 		await self.refresh(player)
 
@@ -434,8 +431,12 @@ class FolderMapListView(MapListView):
 		)
 		await map_in_folder.save()
 
+		# Add the map to the cache to show it on refresh.
+		if self.cache:
+			self.cache.append(await self.map_to_dict(self.app.instance.map_manager.current_map))
+
 		await show_alert(player, 'Map has been added to the folder!', 'sm')
-		await self.display(player)
+		await self.refresh(player)
 
 	async def action_rename(self, player, values, **kwargs):
 		new_name = await ask_input(
@@ -451,6 +452,15 @@ class FolderMapListView(MapListView):
 
 		await self.display(player)
 
+	async def map_to_dict(self, map):
+		dict_item = model_to_dict(map)
+		if any(f['index'] == "local_record" for f in self.fields):
+			dict_item['local_record'] = times.format_time((map.local['first_record'].score if hasattr(map, 'local') and map.local['first_record'] else 0))
+		if any(f['index'] == "karma" for f in self.fields) and 'karma' in self.app.instance.apps.apps:
+			dict_item['karma'] = (await self.app.instance.apps.apps['karma'].get_map_karma(map))['map_karma']
+
+		return dict_item
+
 
 class FolderListView(ManualListView):
 	title = 'Maplist folders'
@@ -539,7 +549,8 @@ class FolderListView(ManualListView):
 			return
 
 		# Check permission on folder.
-		if folder_dictionary['owner_login'] != player.login:
+		# Masteradmins (level 3) are allowed to delete other folders.
+		if folder_dictionary['owner_login'] != player.login and player.level < 3:
 			await show_alert(player, 'You can not remove folders made by others!', size='sm')
 			return
 
